@@ -55,6 +55,8 @@
 #include <glib/gi18n.h>
 #endif
 
+#include <libxfce4util/libxfce4util.h>
+
 #include "xfconf-gvaluefuncs.h"
 #include "xfconf-common-private.h"
 #include "xfconf/xfconf.h"
@@ -133,19 +135,19 @@ static void
 xfconf_query_get_propname_size (gpointer key, gpointer value, gpointer user_data)
 {
     gint *size = user_data;
-    gchar *property_name = (gchar *)key;
+    gchar *propname = (gchar *)key;
 
-    if ((gint) strlen(property_name) > *size)
-        *size = strlen(property_name);
+    if ((gint) strlen(propname) > *size)
+        *size = strlen(propname);
 
 }
 
 static void
 xfconf_query_list_sorted (gpointer key, gpointer value, gpointer user_data)
 {
-  GSList **list = user_data;
+  GSList **listp = user_data;
   
-  *list = g_slist_insert_sorted (*list, key, (GCompareFunc) g_utf8_collate);
+  *listp = g_slist_insert_sorted (*listp, key, (GCompareFunc) g_utf8_collate);
 }
 
 static void
@@ -181,19 +183,19 @@ static GOptionEntry entries[] =
         NULL
     },
     {    "channel", 'c', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING, &channel_name,
-        N_("Pick the channel"),
+        N_("The channel to query/modify"),
         NULL
     },
     {    "property", 'p', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING, &property_name,
-        N_("Pick the property"),
+        N_("The property to query/modify"),
         NULL
     },
     {    "set", 's', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING_ARRAY, &set_value,
-        N_("Change or set the value of the property"),
+        N_("The new value to set for the property"),
         NULL
     },
     {    "list", 'l', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &list,
-        N_("List properties (or channels if -c isn't specified)"),
+        N_("List properties (or channels if -c is not specified)"),
         NULL
     },
     {    "verbose", 'v', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &verbose,
@@ -201,7 +203,7 @@ static GOptionEntry entries[] =
         NULL
     },
     {    "create", 'n', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &create,
-        N_("Create new entry"),
+        N_("Create a new property if it does not already exist"),
         NULL
     },
     {    "type", 't', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING_ARRAY, &type,
@@ -243,6 +245,9 @@ main(int argc, char **argv)
     XfconfChannel *channel = NULL;
     gboolean prop_exists;
     gint fd = -1;
+    GOptionContext *context;
+
+    xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
 
     g_type_init();
     if(!xfconf_init(&error))
@@ -251,8 +256,8 @@ main(int argc, char **argv)
         g_error_free(error);
         return 1;
     }
-    
-    GOptionContext *context = g_option_context_new("- xfconf commandline utility");
+
+    context = g_option_context_new("- xfconf commandline utility");
 
     g_option_context_add_main_entries(context, entries, GETTEXT_PACKAGE);
 
@@ -322,13 +327,15 @@ main(int argc, char **argv)
     
     if (monitor)
     {
+        GMainLoop *loop;
+
         g_signal_connect (G_OBJECT (channel), "property-changed", G_CALLBACK (xfconf_query_monitor), NULL);
         
         g_print ("\n");
         g_print (_("Start monitoring channel '%s':"), channel_name);
         g_print ("\n------------------------------------------------\n\n");
         
-        GMainLoop *loop = g_main_loop_new (NULL, TRUE);
+        loop = g_main_loop_new (NULL, TRUE);
         g_main_loop_run (loop);
         g_main_loop_unref (loop);        
     }
@@ -347,7 +354,7 @@ main(int argc, char **argv)
 
             if(!xfconf_channel_get_property(channel, property_name, &value))
             {
-                g_print(_("Property \"%s\" doesn't exist on channel \"%s\".\n"),
+                g_print(_("Property \"%s\" does not exist on channel \"%s\".\n"),
                         property_name, channel_name);
                 return 1;
             }
@@ -387,15 +394,15 @@ main(int argc, char **argv)
             prop_exists = xfconf_channel_has_property(channel, property_name);
             if(!prop_exists && !create)
             {
-                g_printerr(_("Property \"%s\" does not exist on channel \"%s\".  If you would\n"
-                             "like to create a new property, use the --create option.\n"),
+                g_printerr(_("Property \"%s\" does not exist on channel \"%s\".  If a new\n"
+                             "property should be created, use the --create option.\n"),
                              property_name, channel_name);
                 return 1;
             }
 
             if(!prop_exists && (!type || !type[0]))
             {
-                g_printerr(_("When creating a new property, you must specify the value type.\n"));
+                g_printerr(_("When creating a new property, the value type must be specified.\n"));
                 return 1;
             }
 
@@ -405,7 +412,7 @@ main(int argc, char **argv)
                  * didn't specify one */
                 if(!xfconf_channel_get_property(channel, property_name, &value))
                 {
-                    g_printerr(_("Failed to get existing type for value.\n"));
+                    g_printerr(_("Failed to get the existing type for the value.\n"));
                     return 1;
                 }
             }
@@ -423,13 +430,13 @@ main(int argc, char **argv)
 
                 if(G_TYPE_INVALID == gtype || G_TYPE_NONE == gtype)
                 {
-                    g_printerr(_("Unable to determine type of value.\n"));
+                    g_printerr(_("Unable to determine the type of the value.\n"));
                     return 1;
                 }
 
                 if(XFCONF_TYPE_G_VALUE_ARRAY == gtype)
                 {
-                    g_printerr(_("You must specify a value type to change an array into a single value.\n"));
+                    g_printerr(_("A value type must be specified to change an array into a single value.\n"));
                     return 1;
                 }
 
@@ -471,7 +478,7 @@ main(int argc, char **argv)
 
                 if(new_values != new_types)
                 {
-                    g_printerr(_("Have %d new values, but could only determine %d types.\n"),
+                    g_printerr(_("There are %d new values, but only %d types could be determined.\n"),
                                new_values, new_types);
                     return 1;
                 }
@@ -529,10 +536,11 @@ main(int argc, char **argv)
         if (channel_contents)
         {
             gint size = 0;
+            GSList *sorted_contents = NULL;
+
             if (verbose)
                 g_hash_table_foreach (channel_contents, (GHFunc)xfconf_query_get_propname_size, &size);
             
-            GSList *sorted_contents = NULL;
             g_hash_table_foreach (channel_contents, (GHFunc)xfconf_query_list_sorted, &sorted_contents);
             
             xfconf_query_list_contents (sorted_contents, channel_contents, size);
